@@ -17,7 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
 
-/* $Id: pcsc_scan.c,v 1.21 2006-03-09 13:48:19 rousseau Exp $ */
+/* $Id: pcsc_scan.c,v 1.23 2006-10-25 16:08:10 rousseau Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -159,6 +159,7 @@ get_readers:
 	if (rv != SCARD_S_SUCCESS)
 	{
 		printf("SCardListReader: %lX\n", rv);
+		exit(-1);
 	}
 	dwReadersOld = dwReaders;
 
@@ -325,6 +326,9 @@ get_readers:
 
 			printf("%s\n", color_end);
 
+			/* force display */
+			fflush(stdout);
+
 			/* Also dump the ATR if available */
 			if (rgReaderStates_t[current_reader].cbAtr > 0)
 			{
@@ -343,6 +347,9 @@ get_readers:
 
 				printf("%s%s%s\n\n", magenta, atr, color_end);
 
+				/* force display */
+				fflush(stdout);
+
 				if (analyse_atr)
 				{
 					sprintf(atr_command, ATR_PARSER " '%s'", atr);
